==> am_mod_lbr_0_3.zip: am_mod_lbr_0_3/components/lbr/template/barnraiser_01/page.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
@import url(<?php echo $template_path_core;?>css/aroundme_wiki_formating.css);
@import url(<?php echo $template_path;?>css/lbr.css);
-->
</style>


<form action="index.php?amn=lbr_page" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($set['set_id'])) { echo $set['set_id'];}?>" />
<input type="hidden" name="page_name" value="<?php if(isset($revision['revision_id'])) { echo $revision['revision_id'];}?>" />


<div class="col_main">
	
	<div class="box">
		<div class="box_top">
			<?php echo $page['page_title'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($_SESSION['user_id'])) {
				?>
				
				<div class="metadata_top">
					<?php
					if (isset($page['bookmark']['watch'])) {
					?>
						<input type="image" src="<?php echo $template_path_core;?>img/unmark.png" name="mark" value="0" alt="<?php echo $lang['txt_alt_remove_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_remove_bookmark'];?>" />
					<?php
					}
					else {
					?>
						<input type="image" src="<?php echo $template_path_core;?>img/mark.png" name="mark" value="1" alt="<?php echo $lang['txt_alt_add_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_add_bookmark'];?>" />
						&nbsp;
						<input type="image" src="<?php echo $template_path_core;?>img/track.png" name="mark" value="2" alt="<?php echo $lang['txt_alt_add_track'];?>" title="<?php echo $lang['txt_title_add_track'];?>" border="0" />
					<?php }?>
					
					<?php
					if (isset($participation) && $participation['participation_permission'] & $library_config['resource']['user']['allow_revisioning']) {
					?>
					&nbsp;
					&nbsp;
					<a href="index.php?amn=lbr_revision_edit&amp;revision_id=<?php echo $revision['revision_id'];?>&amp;page_id=<?php echo $page['page_id'];?>"><?php echo $lang['href_edit_page'];?></a>
					<?php }?>
					
					<?php
					if (isset($participation)) {
					?>
					&nbsp;
					&#124;
					&nbsp;
					<?php
					if (isset($relationship)) {
						echo "respected";
						
						if (isset($relationship['mutual'])) {
							echo "<sup>m</sup>";
						}
					}
					elseif(isset($_SESSION['user_id']) && $_SESSION['user_id'] != $revision['user_id']) {
					?>
						<a href="index.php?amn=lbr_page&amp;respect=1&amp;revision_id=<?php echo $revision['revision_id'];?>&amp;set_id=<?php echo $set['set_id'];?>"><?php echo $lang['href_respect'];?></a>
					<?php }?>
					<?php }?>
					<br />
				</div>
				
				<?php }?>
				
				<p style="display:table;">
					<?php echo $revision['revision_body'];?><br />
				</p>
				
				<img src="<?php echo $template_path_core;?>img/pixel.png" width="1" height="12" alt="" /><br />
				
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td>
							<?php
							if (isset($_SESSION['user_id'])) {
							?>
							<?php
							if (isset($page['bookmark']['recommend'])) {
							?>
								<input type="image" src="<?php echo $template_path_core;?>img/unrecommend.png" name="recommend" value="0" alt="<?php echo $lang['txt_alt_remove_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_remove_recommendation'];?>" />
							<?php
							}
							else {
							?>
								<input type="image" src="<?php echo $template_path_core;?>img/recommend.png" name="recommend" value="1" alt="<?php echo $lang['txt_alt_add_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_add_recommendation'];?>" />
							<?php }?>
							&nbsp;
							<?php }?>
							
							<?php echo $this->date->formatDate($revision['revision_create_datetime'],1);?>
							
							<br />
						</td>
						<td align="right">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;set_id=<?php echo $set['set_id'];?>"><?php echo $identity['identity_nic'];?></a>
							
							<?php
							if (isset($common_ties)) {
							?>
							&nbsp; 
							<span class="icon_frame">
							<span class="icon_title"><a href="index.php?amn=core_tie_matrix&amp;identity_id=<?php echo $common_ties['identity_id']; ?>&amp;identity_id_relation=<?php echo $common_ties['identity_id_relation'];?>">matrix</a></span>
							<span class="icon_value"><?php if (isset($common_ties)) echo $common_ties['count_strong'];?></span>
							<span class="icon_value"><?php if (isset($common_ties)) echo $common_ties['count_weak'];?></span>
							</span>
							<?php }?>
							
							<?php
							if (isset($identity['testimonial_count'])) {
							?>
							&nbsp; 
							<span class="icon_frame">
								<span class="icon_title">&nbsp;<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;set_id=<?php echo $set['set_id'];?>"><?php echo $lang['txt_vouched'];?></a>&nbsp;</span>
								<span class="icon_value">&nbsp;<?php echo $identity['testimonial_count'];?>&nbsp;</span>
							</span>
							<?php }?>
					
							<br />
						</td>
					</tr>				
				</table>				
				
				
				<?php
				if (isset($_SESSION['user_id'])) {
				?>
				
				<hr />
				
				<table border="0" cellspacing="0" cellpadding="4">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_relevent'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($page['rate']['relevent']['value']) && $page['rate']['relevent']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="relevent" value="0" title="<?php echo $lang['txt_title_set_not_relevent'];?>" alt="<?php echo $lang['txt_alt_not_relevent'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($page['rate']['relevent']['value']) && $page['rate']['relevent']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="relevent" value="1" title="<?php echo $lang['txt_title_set_relevent'];?>" alt="<?php echo $lang['txt_alt_relevent'];?>" border="0" />
							<?php }?>
							
							
						</td>
						<td valign="top">
							<?php
							if (isset($page['rate']['relevent']['value'])) {
							?>
							<?php echo $lang['txt_relevent_summary'];?><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_accurate'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($page['rate']['accurate']['value']) && $page['rate']['accurate']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="accurate" value="0" title="<?php echo $lang['txt_title_set_not_accurate'];?>" alt="<?php echo $lang['txt_alt_not_accurate'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($page['rate']['accurate']['value']) && $page['rate']['accurate']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="accurate" value="1" title="<?php echo $lang['txt_title_set_accurate'];?>" alt="<?php echo $lang['txt_alt_accurate'];?>" border="0" />
							<?php }?>
						</td>
						<td valign="top">
							<?php
							if (isset($page['rate']['accurate']['value'])) {
							?>
							<?php echo $lang['txt_accurate_summary'];?><br />
							<?php }?>
						</td>
					</tr>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_comments'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				$profile_url = "index.php?amn=core_profile&amp;module_id=" . $core_config['module_id']['library'] . "&amp;item_id=" . $set['set_id'];
				?>
				
				<?php
				include $template_path_core . "inc/comment.inc.php";
				?>
				<hr />
				
				<?php
				if (isset($participation)) {
					include $template_path_core . "inc/add_comment.inc.php";
				}
				else {
					echo $lang['txt_participate_first'];
				}
				?>
				
				</form>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<?php
	if (isset($_SESSION['user_id'])) {
	?>
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_my_participation'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (!empty($participation)) {
				?>
				<table cellspacing="2" cellpadding="2" border="0">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_joined'];?><br />
						</td>
						<td valign="top">
							<?php echo $this->date->formatDate($participation['participation_create_datetime']);?><br />
						</td>
					</tr>
					<?php
					if (isset($participation['role_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_role'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_role'][$participation['role_id']];?><br />
						</td>
					</tr>
					<?php }?>
					
					<?php
					if (isset($participation['status_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_status'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_status'][$participation['status_id']];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
				<?php
				}
				else {
				?>
				<p>
					<?php echo $lang['set_type'][$set['set_type']];?>
				
					<?php
					if (($set['set_type'] == $library_config['type']['membership_type']) || ($set['set_type'] == $library_config['type']['approved']) || ($set['set_type'] == $library_config['type']['open'])) {
					?>
					: <a href="index.php?amn=lbr_participation&amp;set_id=<?php echo $set['set_id'];?>">join</a><br />
					<?php }?>
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_wiki_set'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $set['set_title'];?><br /></b><br />
					<?php echo $set['set_synopsis'];?><br />
				</p>
				
				<?php
				if (isset($my_bookmarks)) {
				?>
				<p>
					<b><?php echo $lang['txt_bookmarked'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
				
				<?php
				if (isset($_SESSION['user_id']) && $_SESSION['user_id'] == $set['user_id']) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_set_edit&amp;set_id=<?php echo $set['set_id'];?>">edit set</a><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<?php echo $lang['hdr_wiki_page'];?><br />
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $page['page_title'];?><br /></b><br />
					<?php echo $page['page_synopsis'];?><br />
				</p>
				
				<p>
					<?php echo $lang['txt_wiki_name'];?>: <?php echo $page['page_name'];?><br />
				</p>
				
				<?php
				if (isset($revisions)) {
				?>
				<p>
					<b><?php echo $lang['hdr_latest_revisions'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach ($revisions as $key => $i):
					if ($i['revision_id'] == $revision['revision_id']) {
					?>
					<?php echo $this->date->formatDate($i['revision_create_datetime'],1);?>
					<?php
					}
					else {
					?>
					<a href="index.php?amn=lbr_page&amp;revision_id=<?php echo $i['revision_id'];?>"><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></a>
					<?php }?>
					
					<?php 
					if ($i['revision_id'] == $page['current_revision_id']) {				
						echo "*";
					}
					?>
					<br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
				
				<?php
				// if I have permissions
				if (isset($participation) && $participation['participation_permission'] & $library_config['resource']['user']['manage_pages']) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_page_edit&amp;page_id=<?php echo $page['page_id'];?>">edit page</a>			
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<?php
	if (isset($_SESSION['user_id'])) {
	?>
	<div class="box">
		<div class="box_top">
			<span style="float:left">
				<img src="<?php echo $template_path_core;?>img/help.png" style="cursor:help;"  title="<?php echo $lang['txt_help'];?>" hspace="2" alt="" border="0" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_tag');" />
			</span>
			
			<?php echo $lang['hdr_tags'];?><br />
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $lang['txt_tags'];?></b><br />
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=lbr_page&amp;page_id=" . $page['page_id'] . "&amp;edit_tag=" . $i['tag_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<table cellspacing="1" cellpadding="0" border="0" width="100%">
					<tr>
						<td>
							<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
							<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
						</td>	
						<td nowrap="nowrap" align="right">
							<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_ok'];?>" /> 
							<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_delete'];?>" /><br />
						</td>
					</tr>
				</table>
			</div>
		</div>
	</div>
	<?php }?>
</div>
</form>

==> am_mod_lbr_0_5.zip: am_mod_lbr_0_5/components/lbr/template/barnraiser_01/page.tpl.php <==
<?php

// -----------------------------------------------------------------------
// This file is part of AROUNDMe
// 
// Copyright (C) 2003 - 2007 Barnraiser
// http://www.barnraiser.org/
// info@barnraiser.org
// 
// This program is free software; you can redistribute it and/or modify it
// under the terms of the GNU General Public License as published by the
// Free Software Foundation; either version 2, or (at your option) any
// later version.
// 
// This program is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
// General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with program; see the file COPYING. If not, write to the Free
// Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
// 02110-1301, USA.
// -----------------------------------------------------------------------
?>

<style type="text/css">
<!--
@import url(<?php echo $template_path_core;?>css/aroundme_form.css);
@import url(<?php echo $template_path_core;?>css/aroundme_wiki_formating.css);
<?php
if (isset($set['set_css'])) {
	echo $set['set_css'];
}
?>
-->
</style>


<form action="index.php?amn=lbr_page" method="post" name="frm" id="id_frm">
<input type="hidden" name="page_id" value="<?php if(isset($page['page_id'])) { echo $page['page_id'];}?>" />
<input type="hidden" name="set_id" value="<?php if(isset($set['set_id'])) { echo $set['set_id'];}?>" />
<input type="hidden" name="page_name" value="<?php if(isset($revision['revision_id'])) { echo $revision['revision_id'];}?>" />


<div class="col_main">
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $page['page_title'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<?php
				if (isset($_SESSION['user_id'])) {
				?>
				
				<div class="metadata_top">
					<?php
					if (isset($page['bookmark']['watch'])) {
					?>
						<input type="image" src="<?php echo $template_path_core;?>img/unmark.png" name="mark_0" value="0" alt="<?php echo $lang['txt_alt_remove_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_remove_bookmark'];?>" />
					<?php
					}
					else {
					?>
						<input type="image" src="<?php echo $template_path_core;?>img/mark.png" name="mark_1" value="1" alt="<?php echo $lang['txt_alt_add_bookmark'];?>" border="0" title="<?php echo $lang['txt_title_add_bookmark'];?>" />
						&nbsp;
						<input type="image" src="<?php echo $template_path_core;?>img/track.png" name="mark_2" value="2" alt="<?php echo $lang['txt_alt_add_track'];?>" title="<?php echo $lang['txt_title_add_track'];?>" border="0" />
					<?php }?>
					
					<?php
					if (isset($participation) && $participation['participation_permission'] & $library_config['resource']['user']['allow_revisioning']) {
					?>
					&nbsp;
					&nbsp;
					<a href="index.php?amn=lbr_revision_edit&amp;revision_id=<?php echo $revision['revision_id'];?>&amp;page_id=<?php echo $page['page_id'];?>"><?php echo $lang['href_edit_page'];?></a>
					<?php }?>
					<br />
				</div>
				
				<?php }?>
				
				<div style="overflow: auto; width:510px;margin-top:6px;margin-bottom:6px;">
					<?php echo $revision['revision_body'];?>
				</div>
				
				<img src="<?php echo $template_path_core;?>img/pixel.png" width="1" height="12" alt="" /><br />
				
				<table cellspacing="0" cellpadding="2" border="0" width="100%">
					<tr>
						<td>
							<?php
							if (isset($_SESSION['user_id'])) {
							?>
							<?php
							if (isset($page['bookmark']['recommend'])) {
							?>
								<input type="image" src="<?php echo $template_path_core;?>img/unrecommend.png" name="recommend_0" value="0" alt="<?php echo $lang['txt_alt_remove_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_remove_recommendation'];?>" />
							<?php
							}
							else {
							?>
								<input type="image" src="<?php echo $template_path_core;?>img/recommend.png" name="recommend_1" value="1" alt="<?php echo $lang['txt_alt_add_recommendation'];?>" border="0" title="<?php echo $lang['txt_title_add_recommendation'];?>" />
							<?php }?>
							&nbsp;
							<?php }?>
							
							<?php if (isset($matrix[0]['relation']) && !isset($matrix[0]['relation']['respected'])) { ?>
								<a href="index.php?amn=lbr_page&amp;respect=1&amp;revision_id=<?php echo $revision['revision_id'];?>&amp;set_id=<?php echo $set['set_id'];?>"><?php echo $lang['href_respect'];?></a>
								&nbsp;
							<?php } ?>
							
							<?php echo $this->date->formatDate($revision['revision_create_datetime'],1);?>
							
							<br />
						</td>
						<td align="right">
							<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;item_id=<?php echo $set['set_id'];?>"><?php echo $identity['identity_nic'];?></a>
							
							<?php
							if (isset($matrix)) {
 								echo drawMatrix($matrix[0]);
							} ?>
							
							<?php
							if (isset($identity['testimonial_count'])) {
							?>
							&nbsp; 
							<span class="icon_frame">
								<span class="icon_title">&nbsp;<a href="index.php?amn=core_profile&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;identity_id=<?php echo $identity['identity_id'];?>&amp;set_id=<?php echo $set['set_id'];?>"><?php echo $lang['txt_vouched'];?></a>&nbsp;</span>
								<span class="icon_value">&nbsp;<?php echo $identity['testimonial_count'];?>&nbsp;</span>
							</span>
							<?php }?>
					
							<br />
						</td>
					</tr>
				</table>
				
				<?php
				if (isset($_SESSION['user_id'])) {
				?>
				
				<hr />
				
				<table border="0" cellspacing="0" cellpadding="4">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_relevent'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($page['rate']['relevent']['value']) && $page['rate']['relevent']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="relevent_0" value="0" title="<?php echo $lang['txt_title_set_not_relevent'];?>" alt="<?php echo $lang['txt_alt_not_relevent'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($page['rate']['relevent']['value']) && $page['rate']['relevent']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_relevent'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="relevent_1" value="1" title="<?php echo $lang['txt_title_set_relevent'];?>" alt="<?php echo $lang['txt_alt_relevent'];?>" border="0" />
							<?php }?>
							
							
						</td>
						<td valign="top">
							<?php
							if (isset($page['rate']['relevent']['value'])) {
							?>
							<?php echo $lang['txt_relevent_summary'];?><br />
							<?php }?>
						</td>
					</tr>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_accurate'];?><br />
						</td>
						<td nowrap="nowrap">
							<?php
							if (isset($page['rate']['accurate']['value']) && $page['rate']['accurate']['value'] == 0) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_down.png" title="<?php echo $lang['txt_title_not_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_down.png" name="accurate_0" value="0" title="<?php echo $lang['txt_title_set_not_accurate'];?>" alt="<?php echo $lang['txt_alt_not_accurate'];?>" border="0" />
							<?php }?>
							
							<?php
							if (isset($page['rate']['accurate']['value']) && $page['rate']['accurate']['value'] == 1) {
							?>
							<img src="<?php echo $template_path_core;?>img/thumb_up.png" title="<?php echo $lang['txt_title_accurate'];?>" border="0" />
							<?php
							}
							else {
							?>
							<input type="image" src="<?php echo $template_path_core;?>img/thumb_up.png" name="accurate_1" value="1" title="<?php echo $lang['txt_title_set_accurate'];?>" alt="<?php echo $lang['txt_alt_accurate'];?>" border="0" />
							<?php }?>
						</td>
						<td valign="top">
							<?php
							if (isset($page['rate']['accurate']['value'])) {
							?>
							<?php echo $lang['txt_accurate_summary'];?><br />
							<?php }?>
						</td>
					</tr>
				</table>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_comments'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				$profile_url = "index.php?amn=core_profile&amp;module_id=" . $core_config['module_id']['library'] . "&amp;item_id=" . $set['set_id'];
				?>
				
				<?php
				include $template_path_core . "inc/comment.inc.php";
				?>
				<hr />
				
				<?php
				if (isset($participation)) {
					include $template_path_core . "inc/add_comment.inc.php";
				}
				else {
					echo $lang['txt_participate_first'];
				}
				?>
				
				</form>
			</div>
		</div>
	</div>
</div>

<div class="col_side">
	<?php
	if (isset($_SESSION['user_id'])) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_my_participation'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<?php
				if (!empty($participation)) {
				?>
				<table cellspacing="2" cellpadding="2" border="0">
					<tr>
						<td valign="top">
							<?php echo $lang['txt_joined'];?><br />
						</td>
						<td valign="top">
							<?php echo $this->date->formatDate($participation['participation_create_datetime']);?><br />
						</td>
					</tr>
					<?php
					if (isset($participation['role_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_role'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_role'][$participation['role_id']];?><br />
						</td>
					</tr>
					<?php }?>
					
					<?php
					if (isset($participation['status_id'])) {
					?>
					<tr>
						<td valign="top">
							<?php echo $lang['txt_status'];?><br />
						</td>
						<td valign="top">
							<?php echo $lang['user_participation_status'][$participation['status_id']];?><br />
						</td>
					</tr>
					<?php }?>
				</table>
				<?php
				}
				else {
				?>
				<p>
					<?php echo $lang['set_type'][$set['set_type']];?>
				
					<?php
					if (($set['set_type'] == $library_config['type']['membership_type']) || ($set['set_type'] == $library_config['type']['approved']) || ($set['set_type'] == $library_config['type']['open'])) {
					?>
					: <a href="index.php?amn=core_participation&amp;module_id=<?php echo $core_config['module_id']['library'];?>&amp;item_id=<?php echo $set['set_id'];?>"><?php echo $lang['href_join'];?></a><br />
					<?php }?>
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	<?php }?>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_wiki_set'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $set['set_title'];?><br /></b><br />
					<?php echo $set['set_synopsis'];?><br />
				</p>
				
				<?php
				if (isset($my_bookmarks)) {
				?>
				<p>
					<b><?php echo $lang['txt_bookmarked'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach($my_bookmarks as $key => $i):
					?>
					<a href="index.php?amn=lbr_page&amp;page_id=<?php echo $i['page_id'];?>"><?php echo $i['page_title'];?></a><br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
				
				<?php
				if (isset($_SESSION['user_id']) && $_SESSION['user_id'] == $set['user_id']) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_set_edit&amp;set_id=<?php echo $set['set_id'];?>">edit set</a><br />
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<div class="box">
		<div class="box_top">
			<div class="content">
				<h1><?php echo $lang['hdr_wiki_page'];?></h1>
			</div>
		</div>
		
		<div class="box_mid">
			<div class="content">
				<p>
					<b><?php echo $page['page_title'];?><br /></b><br />
					<?php echo $page['page_synopsis'];?><br />
				</p>
				
				<p>
					<?php echo $lang['txt_wiki_name'];?>: <?php echo $page['page_name'];?><br />
				</p>
				
				<?php
				if (isset($revisions)) {
				?>
				<p>
					<b><?php echo $lang['hdr_latest_revisions'];?></b><br />
				</p>
				
				<p>
					<?php
					foreach ($revisions as $key => $i):
					if ($i['revision_id'] == $revision['revision_id']) {
					?>
					<?php echo $this->date->formatDate($i['revision_create_datetime'],1);?>
					<?php
					}
					else {
					?>
					<a href="index.php?amn=lbr_page&amp;revision_id=<?php echo $i['revision_id'];?>"><?php echo $this->date->formatDate($i['revision_create_datetime'],1);?></a>
					<?php }?>
					
					<?php 
					if ($i['revision_id'] == $page['current_revision_id']) {				
						echo "*";
					}
					?>
					<br />
					<?php
					endforeach;
					?>
				</p>
				<?php }?>
				
				<?php
				// if I have permissions
				if (isset($participation) && $participation['participation_permission'] & $library_config['resource']['user']['manage_pages']) {
				?>
				<p align="right">
					<a href="index.php?amn=lbr_page_edit&amp;page_id=<?php echo $page['page_id'];?>">edit page</a>			
				</p>
				<?php }?>
			</div>
		</div>
	</div>
	
	<?php
	if (isset($_SESSION['user_id'])) {
	?>
	<div class="box">
		<div class="box_top">
			<div class="content">
				<a href="#" style="float:left;" onClick="javascript:launchPopupWindow('components/core/help.php?help=core_tags');" style="cursor:help;"><img src="<?php echo $template_path_core;?>img/help.png" alt="<?php echo $lang['alt_help'];?>" border="0" /></a>

				<h1><?php echo $lang['hdr_tags'];?></h1>
			</div>
		</div>
			
		<div class="box_mid">
			<div class="content">
				<p>
					<?php
					if (isset($tags)) {
					$prnt = "";
					foreach($tags as $key => $i):
						$prnt .= $i['tag_body'] . "<sup><a href='index.php?amn=lbr_page&amp;page_id=" . $page['page_id'] . "&amp;edit_tag=" . $i['tag_id'] . "' style='text-decoration:none;'>&#43;</a></sup> ";
					endforeach;
					echo $prnt;
					}
					?>
				</p>
				
				<p>
					<input type="hidden" name="tag_id" value="<?php if (isset($tag)) { echo $tag['tag_id'];}?>" />
					<input type="text" class="input1" name="tag_body" size="10" value="<?php if (isset($tag)) { echo $tag['tag_body'];}?>" /><br />
				</p>
				
				<p style="float:right; margin-bottom:0px; margin-top:0px;">
					<input type="submit" name="insert_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_ok'];?>" />
					<input type="submit" name="delete_tag" class="input_submit" style="font-size:60%;" value="<?php echo $lang['sub_tag_delete'];?>" /><br />
				</p>
			</div>
		</div>
	</div>
	<?php }?>
</div>
</form>
